## Contributing to CEMU ##

### License ###

`CEMU` is placed under [license MIT](https://github.com/hugsy/cemu/LICENSE) which provides Open-Source access to the code and its use.

By contributing to `CEMU` code through the _Pull Requests_ mechanism, you accept to release the code written by you under the said license.


### Submitting a Patch ###

1. Fork `CEMU` repository (requires GitHub account). Sending a patch from the `patch` or `git diff --patch` commands is not accepted.
1. Write the changes in your local repo.
    * Respect the coding style (same indentation format, explicit names as possible)
    * Comment your code
1. Submit a pull request **ALWAYS against `dev`** (never `main` - which is reserved for stable code)
1. Contributors will review your patch. If it is approved, the change will be merged via the GitHub, and you will be seen as contributors. If it needs additional work, the repo owner will respond with useful comments.
